--
-- SampleModMap
--
-- @author  Stefan Geiger
-- @date  06/08/12
--
-- Copyright (C) GIANTS Software GmbH, Confidential, All Rights Reserved.

MegaMaisMap = {}

local MegaMaisMap_mt = Class(MegaMaisMap, Mission00);


function MegaMaisMap:new(baseDirectory, customMt)
    local mt = customMt;
    if mt == nil then
        mt = MegaMaisMap_mt;
    end;
    local self = MegaMaisMap:superClass():new(baseDirectory, mt);

--    self.playerStartX = 39;
--    self.playerStartY = 0.1;
--    self.playerStartZ = -330;
--    self.playerRotX = 0;
--    self.playerRotY = Utils.degToRad(90);

    return self;
end;

function MegaMaisMap:delete()
    MegaMaisMap:superClass().delete(self);
end;

function MegaMaisMap:load()
    self:startLoadingTask();

    self.environment = Environment:new(Utils.getFilename("$data/sky/sky_day_night.i3d", self.baseDirectory), true, 8, true, true);

    self.fieldDefinitionBase = nil;
    self.vehicleShopBase = nil;

    self:loadMap(Utils.getFilename("map/map.i3d", self.baseDirectory), true, self.loadMap01Finished, self);
end;

function MegaMaisMap:loadMap01Finished(node, arguments)

    self:loadMapXMLFile(Utils.getFilename("MegaMaisMap.xml", self.baseDirectory));

    self.missionPDA:loadMap(Utils.getFilename("pda_map.png", self.baseDirectory), 2048, 2048);

    g_inGameMenu:setMapViewsMap(Utils.getFilename("pda_map.png", self.baseDirectory));

    local iconSize = self.missionPDA.pdaMapWidth / 15;

    -- Vehicle Shop
    self.missionPDA:createMapHotspot("Shop", Utils.getFilename("$dataS2/missions/hud_pda_spot_shop.png", self.baseDirectory), 1024 - 130, 1024 - 383, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
	
    -- bga
    self.missionPDA:createMapHotspot("TipPlace", Utils.getFilename("$dataS2/missions/hud_pda_spot_tipPlace.png", self.baseDirectory), 1024 + 395.1, 1024 - 693.7, iconSize, iconSize * (4 / 3), false, false, false, 0, true);

    -- livestock
    self.missionPDA:createMapHotspot("Cows", Utils.getFilename("$dataS2/missions/hud_pda_spot_cows.png", self.baseDirectory), 1024 + 256, 1024 + 655, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("Sheep", Utils.getFilename("$dataS2/missions/hud_pda_spot_sheep.png", self.baseDirectory), 1024 - 600, 1024 + 585, iconSize, iconSize * (4 / 3), false, false, false, 0, true);
    self.missionPDA:createMapHotspot("Chickens", Utils.getFilename("$dataS2/missions/hud_pda_spot_chickens.png", self.baseDirectory), 1024 - 12, 1024 - 93, iconSize, iconSize * (4 / 3), false, false, false, 0, true);

    MegaMaisMap:superClass().load(self);

    if not self.missionDynamicInfo.isMultiplayer then
        self:updateFoundHorseshoes();
        self:updateFoundHelpIcons();
        self:updateMeteoriteCrash();
        self:updateRainbow();
    else
        self:removeAllHorseshoes();
        self:removeAllHelpIcons();
    end;

    if g_isGamescomVersion then
        self:playerOwnsAllFields();
    end;

    self:finishLoadingTask();
end;

function MegaMaisMap:onStartMission()
    MegaMaisMap:superClass().onStartMission(self);
end;

function MegaMaisMap:mouseEvent(posX, posY, isDown, isUp, button)
    MegaMaisMap:superClass().mouseEvent(self, posX, posY, isDown, isUp, button);
end;

function MegaMaisMap:keyEvent(unicode, sym, modifier, isDown)
    MegaMaisMap:superClass().keyEvent(self, unicode, sym, modifier, isDown);
end;

function MegaMaisMap:update(dt)
    MegaMaisMap:superClass().update(self, dt);
end;

function MegaMaisMap:draw()
    MegaMaisMap:superClass().draw(self);
end;